@@ -63,6 +63,8 @@
 #include "transferlistfilterswidget.h"
 #include "propertieswidget.h"
 #include "statusbar.h"
+#include "hidabletabwidget.h"
+#include "qinisettings.h"
 #ifdef Q_WS_MAC
 #include "qmacapplication.h"
 void qt_mac_set_dock_menu(QMenu *menu);
@@ -79,10 +81,11 @@ using namespace libtorrent;
  *****************************************************/
 
 // Constructor
-GUI::GUI(QWidget *parent, QStringList torrentCmdLine) : QMainWindow(parent), displaySpeedInTitle(false), force_exit(false) {
+GUI::GUI(QWidget *parent, QStringList torrentCmdLine) : QMainWindow(parent), force_exit(false) {
   setupUi(this);
 
   setWindowTitle(tr("qBittorrent %1", "e.g: qBittorrent v0.x").arg(QString::fromUtf8(VERSION)));
+  displaySpeedInTitle = Preferences::speedInTitleBar();
   // Setting icons
   this->setWindowIcon(QIcon(QString::fromUtf8(":/Icons/skin/qbittorrent32.png")));
   actionOpen->setIcon(QIcon(QString::fromUtf8(":/Icons/skin/open.png")));
@@ -125,7 +128,7 @@ GUI::GUI(QWidget *parent, QStringList torrentCmdLine) : QMainWindow(parent), dis
 #endif
 
   qDebug("create tabWidget");
-  tabs = new QTabWidget();
+  tabs = new HidableTabWidget();
   connect(tabs, SIGNAL(currentChanged(int)), this, SLOT(tab_changed(int)));
   vSplitter = new QSplitter(Qt::Horizontal);
   //vSplitter->setChildrenCollapsible(false);
@@ -143,6 +146,7 @@ GUI::GUI(QWidget *parent, QStringList torrentCmdLine) : QMainWindow(parent), dis
   vSplitter->setCollapsible(0, true);
   vSplitter->setCollapsible(1, false);
   tabs->addTab(vSplitter, QIcon(QString::fromUtf8(":/Icons/oxygen/folder-remote.png")), tr("Transfers"));
+  connect(transferList, SIGNAL(torrentStatusUpdate(uint,uint,uint,uint,uint)), this, SLOT(updateNbTorrents(uint,uint,uint,uint,uint)));
   vboxLayout->addWidget(tabs);
 
   // Transfer list slots
@@ -154,10 +158,6 @@ GUI::GUI(QWidget *parent, QStringList torrentCmdLine) : QMainWindow(parent), dis
   connect(actionIncreasePriority, SIGNAL(triggered()), transferList, SLOT(increasePrioSelectedTorrents()));
   connect(actionDecreasePriority, SIGNAL(triggered()), transferList, SLOT(decreasePrioSelectedTorrents()));
 
-  // Search engine tab
-  searchEngine = new SearchEngine(this, BTSession);
-  tabs->addTab(searchEngine, QIcon(QString::fromUtf8(":/Icons/oxygen/edit-find.png")), tr("Search"));
-
   // Configure BT session according to options
   loadPreferences(false);
   // Resume unfinished torrents
@@ -180,6 +180,14 @@ GUI::GUI(QWidget *parent, QStringList torrentCmdLine) : QMainWindow(parent), dis
   setUnifiedTitleAndToolBarOnMac(true);
 #endif
 
+  // View settings
+  actionTop_tool_bar->setChecked(Preferences::isToolbarDisplayed());
+  actionSpeed_in_title_bar->setChecked(Preferences::speedInTitleBar());
+  actionRSS_Reader->setChecked(Preferences::isRSSEnabled());
+  actionSearch_engine->setChecked(Preferences::isSearchEnabled());
+  displaySearchTab(actionSearch_engine->isChecked());
+  displayRSSTab(actionRSS_Reader->isChecked());
+
   show();
 
   // Load Window state and sizes
@@ -246,7 +254,8 @@ GUI::~GUI() {
     delete downloadFromURLDialog;
   if(rssWidget)
     delete rssWidget;
-  delete searchEngine;
+  if(searchEngine)
+    delete searchEngine;
   delete transferListFilters;
   delete properties;
   delete hSplitter;
@@ -286,13 +295,40 @@ void GUI::displayRSSTab(bool enable) {
       int index_tab = tabs->addTab(rssWidget, tr("RSS"));
       tabs->setTabIcon(index_tab, QIcon(QString::fromUtf8(":/Icons/rss32.png")));
     }
+    tabs->showTabBar(true);
   } else {
     if(rssWidget) {
       delete rssWidget;
     }
+    if(!searchEngine)
+      tabs->showTabBar(false);
   }
 }
 
+void GUI::displaySearchTab(bool enable) {
+  if(enable) {
+    // RSS tab
+    if(!searchEngine) {
+      searchEngine = new SearchEngine(this, BTSession);
+      tabs->insertTab(1, searchEngine, QIcon(QString::fromUtf8(":/Icons/oxygen/edit-find.png")), tr("Search"));
+    }
+    tabs->showTabBar(true);
+  } else {
+    if(searchEngine) {
+      delete searchEngine;
+    }
+    if(!rssWidget)
+      tabs->showTabBar(false);
+  }
+}
+
+void GUI::updateNbTorrents(unsigned int nb_downloading, unsigned int nb_seeding, unsigned int nb_active, unsigned int nb_inactive, unsigned int nb_paused) {
+  Q_UNUSED(nb_downloading);
+  Q_UNUSED(nb_seeding);
+  Q_UNUSED(nb_paused);
+  tabs->setTabText(0, tr("Transfers (%1)").arg(QString::number(nb_inactive+nb_active)));
+}
+
 void GUI::on_actionWebsite_triggered() const {
   QDesktopServices::openUrl(QUrl(QString::fromUtf8("http://www.qbittorrent.org")));
 }
@@ -306,19 +342,25 @@ void GUI::on_actionBugReport_triggered() const {
 }
 
 void GUI::tab_changed(int new_tab) {
-  if(new_tab == TAB_TRANSFER) {
+  Q_UNUSED(new_tab);
+  // We cannot rely on the index new_tab
+  // because the tab order is undetermined now
+  if(tabs->currentWidget() == vSplitter) {
     qDebug("Changed tab to transfer list, refreshing the list");
     transferList->refreshList();
     properties->loadDynamicData();
+    return;
+  }
+  if(tabs->currentWidget() == searchEngine) {
+    qDebug("Changed tab to search engine, giving focus to search input");
+    searchEngine->giveFocusToSearchInput();
   }
 }
 
 void GUI::writeSettings() {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   settings.beginGroup(QString::fromUtf8("MainWindow"));
-  settings.setValue("IsMaximized", isMaximized());
-  settings.setValue(QString::fromUtf8("size"), size());
-  settings.setValue(QString::fromUtf8("pos"), pos());
+  settings.setValue("geometry", saveGeometry());
   // Splitter size
   QStringList sizes_str;
   sizes_str << QString::number(vSplitter->sizes().first());
@@ -364,27 +406,26 @@ void GUI::createKeyboardShortcuts() {
 
 // Keyboard shortcuts slots
 void GUI::displayTransferTab() const {
-  tabs->setCurrentIndex(TAB_TRANSFER);
+  tabs->setCurrentWidget(transferList);
 }
 
 void GUI::displaySearchTab() const {
-  tabs->setCurrentIndex(TAB_SEARCH);
+  if(searchEngine)
+    tabs->setCurrentWidget(searchEngine);
 }
 
 void GUI::displayRSSTab() const {
-  tabs->setCurrentIndex(TAB_RSS);
+  if(rssWidget)
+    tabs->setCurrentWidget(rssWidget);
 }
 
 // End of keyboard shortcuts slots
 
 void GUI::readSettings() {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   settings.beginGroup(QString::fromUtf8("MainWindow"));
-  resize(settings.value(QString::fromUtf8("size"), size()).toSize());
-  move(settings.value(QString::fromUtf8("pos"), misc::screenCenter(this)).toPoint());
-  if(settings.value("IsMaximized", false).toBool())
-    showMaximized();
-  const QStringList &sizes_str = settings.value("vSplitterSizes", QStringList()).toStringList();
+  restoreGeometry(settings.value("geometry").toByteArray());
+  const QStringList sizes_str = settings.value("vSplitterSizes", QStringList()).toStringList();
   // Splitter size
   QList<int> sizes;
   if(sizes_str.size() == 2) {
@@ -411,10 +452,21 @@ void GUI::balloonClicked() {
 }
 
 void GUI::askRecursiveTorrentDownloadConfirmation(QTorrentHandle &h) {
-  if(QMessageBox::question(this, tr("Recursive download confirmation"), tr("The torrent %1 contains torrent files, do you want to proceed with their download?").arg(h.name()), QMessageBox::Yes|QMessageBox::No) == QMessageBox::Yes) {
-    BTSession->recursiveTorrentDownload(h);
-  }
-}
+  if(Preferences::recursiveDownloadDisabled()) return;
+  QMessageBox confirmBox(QMessageBox::Question, tr("Recursive download confirmation"), tr("The torrent %1 contains torrent files, do you want to proceed with their download?").arg(h.name()));
+  QPushButton *yes = confirmBox.addButton(tr("Yes"), QMessageBox::YesRole);
+  /*QPushButton *no = */confirmBox.addButton(tr("No"), QMessageBox::NoRole);
+                        QPushButton *never = confirmBox.addButton(tr("Never"), QMessageBox::NoRole);
+                        confirmBox.exec();
+                        if(confirmBox.clickedButton() == 0) return;
+                        if(confirmBox.clickedButton() == yes) {
+                          BTSession->recursiveTorrentDownload(h);
+                          return;
+                        }
+                        if(confirmBox.clickedButton() == never) {
+                          Preferences::disableRecursiveDownload();
+                        }
+                      }
 
 void GUI::handleDownloadFromUrlFailure(QString url, QString reason) const{
   // Display a message box
@@ -464,10 +516,12 @@ void GUI::on_actionExit_triggered() {
   close();
 }
 
-int GUI::getCurrentTabIndex() const {
+QWidget* GUI::getCurrentTabWidget() const {
   if(isMinimized() || !isVisible())
-    return -1;
-  return tabs->currentIndex();
+    return 0;
+  if(tabs->currentIndex() == 0)
+    return transferList;
+  return tabs->currentWidget();
 }
 
 void GUI::setTabText(int index, QString text) const {
@@ -506,7 +560,7 @@ void GUI::on_actionAbout_triggered() {
 
 void GUI::showEvent(QShowEvent *e) {
   qDebug("** Show Event **");
-  if(getCurrentTabIndex() == TAB_TRANSFER) {
+  if(getCurrentTabWidget() == transferList) {
     qDebug("-> Refreshing transfer list");
     transferList->refreshList();
     properties->loadDynamicData();
@@ -516,27 +570,35 @@ void GUI::showEvent(QShowEvent *e) {
 
 // Called when we close the program
 void GUI::closeEvent(QCloseEvent *e) {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   const bool goToSystrayOnExit = settings.value(QString::fromUtf8("Preferences/General/CloseToTray"), false).toBool();
   if(!force_exit && systrayIcon && goToSystrayOnExit && !this->isHidden()) {
     hide();
-    //e->ignore();
     e->accept();
     return;
   }
   if(settings.value(QString::fromUtf8("Preferences/General/ExitConfirm"), true).toBool() && BTSession->hasActiveTorrents()) {
-    show();
-    if(!isMaximized())
-      showNormal();
     if(e->spontaneous() || force_exit) {
-      if(QMessageBox::question(this,
-                               tr("Are you sure you want to quit?")+QString::fromUtf8(" -- ")+tr("qBittorrent"),
-                               tr("Some files are currently transferring.\nAre you sure you want to quit qBittorrent?"),
-                               QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes) == QMessageBox::No) {
+      if(!isVisible())
+        show();
+      QMessageBox confirmBox(QMessageBox::Question, tr("Exiting qBittorrent"),
+                             tr("Some files are currently transferring.\nAre you sure you want to quit qBittorrent?"),
+                             QMessageBox::NoButton, this);
+      QPushButton *noBtn = confirmBox.addButton(tr("No"), QMessageBox::NoRole);
+      QPushButton *yesBtn = confirmBox.addButton(tr("Yes"), QMessageBox::YesRole);
+      QPushButton *alwaysBtn = confirmBox.addButton(tr("Always"), QMessageBox::YesRole);
+      confirmBox.setDefaultButton(yesBtn);
+      confirmBox.exec();
+      if(!confirmBox.clickedButton() || confirmBox.clickedButton() == noBtn) {
+        // Cancel exit
         e->ignore();
         force_exit = false;
         return;
       }
+      if(confirmBox.clickedButton() == alwaysBtn) {
+        // Remember choice
+        Preferences::setConfirmOnExit(false);
+      }
     }
   }
   hide();
@@ -551,7 +613,6 @@ void GUI::closeEvent(QCloseEvent *e) {
   qApp->exit();
 }
 
-
 // Display window to create a torrent
 void GUI::on_actionCreate_torrent_triggered() {
   if(createTorrentDlg) {
@@ -563,21 +624,47 @@ void GUI::on_actionCreate_torrent_triggered() {
 }
 
 bool GUI::event(QEvent * e) {
-  if(e->type() == QEvent::WindowStateChange) {
-    qDebug("Window change event");
-    //Now check to see if the window is minimised
-    if(isMinimized()) {
-      qDebug("minimisation");
-      QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-      if(systrayIcon && settings.value(QString::fromUtf8("Preferences/General/MinimizeToTray"), false).toBool()) {
-        if(!qApp->activeWindow() || !qApp->activeWindow()->isModal()) {
-          qDebug("Minimize to Tray enabled, hiding!");
-          e->accept();
-          QTimer::singleShot(0, this, SLOT(hide()));
-          return true; 
+  switch(e->type()) {
+  case QEvent::WindowStateChange: {
+      qDebug("Window change event");
+      //Now check to see if the window is minimised
+      if(isMinimized()) {
+        qDebug("minimisation");
+        QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+        if(systrayIcon && settings.value(QString::fromUtf8("Preferences/General/MinimizeToTray"), false).toBool()) {
+          qDebug("Has active window: %d", (int)(qApp->activeWindow() != 0));
+          // Check if there is a modal window
+          bool has_modal_window = false;
+          foreach (QWidget *widget, QApplication::allWidgets()) {
+            if(widget->isModal()) {
+              has_modal_window = true;
+              break;
+            }
+          }
+          // Iconify if there is no modal window
+          if(!has_modal_window) {
+            qDebug("Minimize to Tray enabled, hiding!");
+            e->accept();
+            QTimer::singleShot(0, this, SLOT(hide()));
+            return true;
+          }
         }
       }
+      break;
     }
+#ifdef Q_WS_MAC
+  case QEvent::ToolBarChange: {
+      qDebug("MAC: Received a toolbar change event!");
+      bool ret = QMainWindow::event(e);
+
+      qDebug("MAC: new toolbar visibility is %d", !actionTop_tool_bar->isChecked());
+      actionTop_tool_bar->toggle();
+      Preferences::setToolbarDisplayed(actionTop_tool_bar->isChecked());
+      return ret;
+    }
+#endif
+  default:
+    break;
   }
   return QMainWindow::event(e);
 }
@@ -587,7 +674,7 @@ void GUI::dropEvent(QDropEvent *event) {
   event->acceptProposedAction();
   QStringList files;
   if(event->mimeData()->hasUrls()) {
-    const QList<QUrl> &urls = event->mimeData()->urls();
+    const QList<QUrl> urls = event->mimeData()->urls();
     foreach(const QUrl &url, urls) {
       const QString tmp = url.toString().trimmed();
       if(!tmp.isEmpty())
@@ -597,15 +684,23 @@ void GUI::dropEvent(QDropEvent *event) {
     files = event->mimeData()->text().split(QString::fromUtf8("\n"));
   }
   // Add file to download list
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   const bool useTorrentAdditionDialog = settings.value(QString::fromUtf8("Preferences/Downloads/AdditionDialog"), true).toBool();
   foreach(QString file, files) {
+#ifdef Q_WS_WIN
+    file = file.trimmed().replace(QString::fromUtf8("file:///"), QString::fromUtf8(""), Qt::CaseInsensitive);
+#else
     file = file.trimmed().replace(QString::fromUtf8("file://"), QString::fromUtf8(""), Qt::CaseInsensitive);
+#endif
     qDebug("Dropped file %s on download list", file.toLocal8Bit().data());
     if(file.startsWith(QString::fromUtf8("http://"), Qt::CaseInsensitive) || file.startsWith(QString::fromUtf8("ftp://"), Qt::CaseInsensitive) || file.startsWith(QString::fromUtf8("https://"), Qt::CaseInsensitive)) {
       BTSession->downloadFromUrl(file);
       continue;
     }
+    if(file.startsWith("bc://bt/", Qt::CaseInsensitive)) {
+      qDebug("Converting bc link to magnet link");
+      file = misc::bcLinkToMagnet(file);
+    }
     if(file.startsWith("magnet:", Qt::CaseInsensitive)) {
       // FIXME: Possibly skipped torrent addition dialog
       BTSession->addMagnetUri(file);
@@ -639,10 +734,10 @@ void GUI::dragEnterEvent(QDragEnterEvent *event) {
 // Display a dialog to allow user to add
 // torrents to download list
 void GUI::on_actionOpen_triggered() {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   // Open File Open Dialog
   // Note: it is possible to select more than one file
-  const QStringList &pathsList = QFileDialog::getOpenFileNames(0,
+  const QStringList pathsList = QFileDialog::getOpenFileNames(0,
                                                                tr("Open Torrent Files"), settings.value(QString::fromUtf8("MainWindowLastDir"), QDir::homePath()).toString(),
                                                                tr("Torrent Files")+QString::fromUtf8(" (*.torrent)"));
   if(!pathsList.empty()) {
@@ -672,13 +767,17 @@ void GUI::processParams(const QString& params_str) {
 }
 
 void GUI::processParams(const QStringList& params) {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   const bool useTorrentAdditionDialog = settings.value(QString::fromUtf8("Preferences/Downloads/AdditionDialog"), true).toBool();
   foreach(QString param, params) {
     param = param.trimmed();
     if(param.startsWith(QString::fromUtf8("http://"), Qt::CaseInsensitive) || param.startsWith(QString::fromUtf8("ftp://"), Qt::CaseInsensitive) || param.startsWith(QString::fromUtf8("https://"), Qt::CaseInsensitive)) {
       BTSession->downloadFromUrl(param);
     }else{
+      if(param.startsWith("bc://bt/", Qt::CaseInsensitive)) {
+        qDebug("Converting bc link to magnet link");
+        param = misc::bcLinkToMagnet(param);
+      }
       if(param.startsWith("magnet:", Qt::CaseInsensitive)) {
         if(useTorrentAdditionDialog) {
           torrentAdditionDialog *dialog = new torrentAdditionDialog(this, BTSession);
@@ -703,7 +802,7 @@ void GUI::addTorrent(QString path) {
 }
 
 void GUI::processDownloadedFiles(QString path, QString url) {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   const bool useTorrentAdditionDialog = settings.value(QString::fromUtf8("Preferences/Downloads/AdditionDialog"), true).toBool();
   if(useTorrentAdditionDialog) {
     torrentAdditionDialog *dialog = new torrentAdditionDialog(this, BTSession);
@@ -746,12 +845,6 @@ void GUI::loadPreferences(bool configure_session) {
   }
 #endif
   // General
-  const bool new_displaySpeedInTitle = Preferences::speedInTitleBar();
-  if(!new_displaySpeedInTitle && new_displaySpeedInTitle != displaySpeedInTitle) {
-    // Reset title
-    setWindowTitle(tr("qBittorrent %1", "e.g: qBittorrent vx.x").arg(QString::fromUtf8(VERSION)));
-  }
-  displaySpeedInTitle = new_displaySpeedInTitle;
   if(Preferences::isToolbarDisplayed()) {
     toolBar->setVisible(true);
     toolBar->layout()->setSpacing(7);
@@ -785,14 +878,6 @@ void GUI::loadPreferences(bool configure_session) {
     }
   }
 
-  // RSS
-  if(Preferences::isRSSEnabled()) {
-    displayRSSTab(true);
-    rssWidget->updateRefreshInterval(Preferences::getRSSRefreshInterval());
-  } else {
-    displayRSSTab(false);
-  }
-
   // Torrent properties
   properties->reloadPreferences();
 
@@ -847,25 +932,23 @@ void GUI::updateGUI() {
 }
 
 void GUI::showNotificationBaloon(QString title, QString msg) const {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-  if(settings.value(QString::fromUtf8("Preferences/General/NotificationBaloons"), true).toBool()) {
+  if(!Preferences::useProgramNotification()) return;
 #ifdef WITH_LIBNOTIFY
-    if (notify_init ("summary-body")) {
-      NotifyNotification* notification;
-      notification = notify_notification_new (qPrintable(title), qPrintable(msg), "qbittorrent", 0);
-      gboolean success = notify_notification_show (notification, NULL);
-      g_object_unref(G_OBJECT(notification));
-      notify_uninit ();
-      if(success) {
-        return;
-      }
+  if (notify_init ("summary-body")) {
+    NotifyNotification* notification;
+    notification = notify_notification_new (qPrintable(title), qPrintable(msg), "qbittorrent", 0);
+    gboolean success = notify_notification_show (notification, NULL);
+    g_object_unref(G_OBJECT(notification));
+    notify_uninit ();
+    if(success) {
+      return;
     }
+  }
 #endif
 #ifndef Q_WS_MAC
-    if(systrayIcon)
-      systrayIcon->showMessage(title, msg, QSystemTrayIcon::Information, TIME_TRAY_BALLOON);
+  if(systrayIcon && QSystemTrayIcon::supportsMessages())
+    systrayIcon->showMessage(title, msg, QSystemTrayIcon::Information, TIME_TRAY_BALLOON);
 #endif
-  }
 }
 
 /*****************************************************
@@ -875,9 +958,13 @@ void GUI::showNotificationBaloon(QString title, QString msg) const {
  *****************************************************/
 
 void GUI::downloadFromURLList(const QStringList& url_list) {
-  QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
+  QIniSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   const bool useTorrentAdditionDialog = settings.value(QString::fromUtf8("Preferences/Downloads/AdditionDialog"), true).toBool();
-  foreach(const QString& url, url_list) {
+  foreach(QString url, url_list) {
+    if(url.startsWith("bc://bt/", Qt::CaseInsensitive)) {
+      qDebug("Converting bc link to magnet link");
+      url = misc::bcLinkToMagnet(url);
+    }
     if(url.startsWith("magnet:", Qt::CaseInsensitive)) {
       if(useTorrentAdditionDialog) {
         torrentAdditionDialog *dialog = new torrentAdditionDialog(this, BTSession);
@@ -923,7 +1010,7 @@ void GUI::createSystrayDelayed() {
 }
 
 void GUI::updateAltSpeedsBtn(bool alternative) {
-    actionUse_alternative_speed_limits->setChecked(alternative);
+  actionUse_alternative_speed_limits->setChecked(alternative);
 }
 
 QMenu* GUI::getTrayIconMenu() {
@@ -973,6 +1060,31 @@ void GUI::on_actionOptions_triggered() {
   }
 }
 
+void GUI::on_actionTop_tool_bar_triggered() {
+  bool is_visible = static_cast<QAction*>(sender())->isChecked();
+  toolBar->setVisible(is_visible);
+  Preferences::setToolbarDisplayed(is_visible);
+}
+
+void GUI::on_actionSpeed_in_title_bar_triggered() {
+  displaySpeedInTitle = static_cast<QAction*>(sender())->isChecked();
+  Preferences::showSpeedInTitleBar(displaySpeedInTitle);
+  if(displaySpeedInTitle)
+    updateGUI();
+  else
+    setWindowTitle(tr("qBittorrent %1", "e.g: qBittorrent v0.x").arg(QString::fromUtf8(VERSION)));
+}
+
+void GUI::on_actionRSS_Reader_triggered() {
+  Preferences::setRSSEnabled(actionRSS_Reader->isChecked());
+  displayRSSTab(actionRSS_Reader->isChecked());
+}
+
+void GUI::on_actionSearch_engine_triggered() {
+  Preferences::setSearchEnabled(actionSearch_engine->isChecked());
+  displaySearchTab(actionSearch_engine->isChecked());
+}
+
 /*****************************************************
  *                                                   *
  *                 HTTP Downloader                   *
