@@ -37,8 +37,6 @@
 #include "ui_mainwindow.h"
 #include "qtorrenthandle.h"
 
-enum TabIndex{TAB_TRANSFER, TAB_SEARCH, TAB_RSS};
-
 class Bittorrent;
 class QTimer;
 class downloadFromURL;
@@ -58,6 +56,7 @@ class consoleDlg;
 class about;
 class createtorrent;
 class downloadFromURL;
+class HidableTabWidget;
 
 class GUI : public QMainWindow, private Ui::MainWindow{
   Q_OBJECT
@@ -67,7 +66,7 @@ public:
   GUI(QWidget *parent=0, QStringList torrentCmdLine=QStringList());
   ~GUI();
   // Methods
-  int getCurrentTabIndex() const;
+  QWidget* getCurrentTabWidget() const;
   TransferListWidget* getTransferList() const { return transferList; }
   QMenu* getTrayIconMenu();
 
@@ -77,6 +76,7 @@ public slots:
   void showNotificationBaloon(QString title, QString msg) const;
   void downloadFromURLList(const QStringList& urls);
   void updateAltSpeedsBtn(bool alternative);
+  void updateNbTorrents(unsigned int nb_downloading, unsigned int nb_seeding, unsigned int nb_active, unsigned int nb_inactive, unsigned int nb_paused);
 
 protected slots:
   // GUI related slots
@@ -127,6 +127,7 @@ protected:
   void showEvent(QShowEvent *);
   bool event(QEvent * event);
   void displayRSSTab(bool enable);
+  void displaySearchTab(bool enable);
 
 private:
   // Bittorrent
@@ -134,7 +135,7 @@ private:
   QList<QPair<QTorrentHandle,QString> > unauthenticated_trackers; // Still needed?
   // GUI related
   QTimer *guiUpdater;
-  QTabWidget *tabs;
+  HidableTabWidget *tabs;
   StatusBar *status_bar;
   QPointer<options_imp> options;
   QPointer<consoleDlg> console;
@@ -160,9 +161,15 @@ private:
   QSplitter *hSplitter;
   QSplitter *vSplitter;
   // Search
-  SearchEngine *searchEngine;
+  QPointer<SearchEngine> searchEngine;
   // RSS
   QPointer<RSSImp> rssWidget;
+
+private slots:
+    void on_actionSearch_engine_triggered();
+    void on_actionRSS_Reader_triggered();
+    void on_actionSpeed_in_title_bar_triggered();
+    void on_actionTop_tool_bar_triggered();
 };
 
 #endif
