@@ -37,6 +37,7 @@
 #include <boost/filesystem/fstream.hpp>
 #include <boost/bind.hpp>
 
+#include <libtorrent/version.hpp>
 #include <libtorrent/entry.hpp>
 #include <libtorrent/bencode.hpp>
 #include <libtorrent/torrent_info.hpp>
@@ -67,7 +68,7 @@ createtorrent::createtorrent(QWidget *parent): QDialog(parent){
   setAttribute(Qt::WA_DeleteOnClose);
   setModal(true);
   creatorThread = new torrentCreatorThread(this);
-  connect(creatorThread, SIGNAL(creationSuccess(QString, const char*)), this, SLOT(handleCreationSuccess(QString, const char*)));
+  connect(creatorThread, SIGNAL(creationSuccess(QString, QString)), this, SLOT(handleCreationSuccess(QString, QString)));
   connect(creatorThread, SIGNAL(creationFailure(QString)), this, SLOT(handleCreationFailure(QString)));
   connect(creatorThread, SIGNAL(updateProgress(int)), this, SLOT(updateProgressBar(int)));
   path::default_name_check(no_check);
@@ -80,14 +81,22 @@ createtorrent::~createtorrent() {
 
 void createtorrent::on_addFolder_button_clicked(){
   QString dir = QFileDialog::getExistingDirectory(this, tr("Select a folder to add to the torrent"), QDir::homePath(), QFileDialog::ShowDirsOnly);
-  if(!dir.isEmpty())
+  if(!dir.isEmpty()) {
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    dir = dir.replace("/", "\\");
+#endif
     textInputPath->setText(dir);
+  }
 }
 
 void createtorrent::on_addFile_button_clicked(){
   QString file = QFileDialog::getOpenFileName(this, tr("Select a file to add to the torrent"), QDir::homePath());
-  if(!file.isEmpty())
+  if(!file.isEmpty()) {
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    file = file.replace("/", "\\");
+#endif
     textInputPath->setText(file);
+  }
 }
 
 void createtorrent::on_removeTracker_button_clicked() {
@@ -179,28 +188,41 @@ void createtorrent::on_createButton_clicked(){
   } else {
     return;
   }
+  // Disable dialog
+  setEnabled(false);
+  // Set busy cursor
+  setCursor(QCursor(Qt::WaitCursor));
+  // Actually create the torrent
   QStringList url_seeds = allItems(URLSeeds_list);
   QString comment = txt_comment->toPlainText();
   creatorThread->create(input, destination, trackers, url_seeds, comment, check_private->isChecked(), getPieceSize());
 }
 
 void createtorrent::handleCreationFailure(QString msg) {
+  // Enable dialog
+  setEnabled(true);
+  // Remove busy cursor
+  setCursor(QCursor(Qt::ArrowCursor));
   QMessageBox::information(0, tr("Torrent creation"), tr("Torrent creation was unsuccessful, reason: %1").arg(msg));
 }
 
-void createtorrent::handleCreationSuccess(QString path, const char* branch_path) {
+void createtorrent::handleCreationSuccess(QString path, QString branch_path) {
+  // Enable Dialog
+  setEnabled(true);
+  // Remove busy cursor
+  setCursor(QCursor(Qt::ArrowCursor));
   if(checkStartSeeding->isChecked()) {
     // Create save path temp data
     boost::intrusive_ptr<torrent_info> t;
     try {
-      t = new torrent_info(path.toLocal8Bit().data());
+      t = new torrent_info(path.toUtf8().data());
     } catch(std::exception&) {
       QMessageBox::critical(0, tr("Torrent creation"), tr("Created torrent file is invalid. It won't be added to download list."));
       return;
     }
     QString hash = misc::toQString(t->info_hash());
-    TorrentTempData::setSavePath(hash, QString(branch_path));
-#ifdef LIBTORRENT_0_15
+    TorrentTempData::setSavePath(hash, branch_path);
+#if LIBTORRENT_VERSION_MINOR > 14
     // Enable seeding mode (do not recheck the files)
     TorrentTempData::setSeedingMode(hash, true);
 #endif
@@ -210,6 +232,18 @@ void createtorrent::handleCreationSuccess(QString path, const char* branch_path)
   close();
 }
 
+void createtorrent::on_cancelButton_clicked() {
+  // End torrent creation thread
+  if(creatorThread->isRunning()) {
+    creatorThread->abortCreation();
+    creatorThread->terminate();
+    // Wait for termination
+    creatorThread->wait();
+  }
+  // Close the dialog
+  reject();
+}
+
 void createtorrent::updateProgressBar(int progress) {
   progressBar->setValue(progress);
 }
@@ -264,7 +298,7 @@ void torrentCreatorThread::run() {
     // Set qBittorrent as creator and add user comment to
     // torrent_info structure
     t.set_creator(creator_str);
-    t.set_comment((const char*)comment.toLocal8Bit());
+    t.set_comment((const char*)comment.toUtf8());
     // Is private ?
     t.set_priv(is_private);
     if(abort) return;
@@ -272,7 +306,7 @@ void torrentCreatorThread::run() {
     ofstream out(complete(path((const char*)save_path.toLocal8Bit())), std::ios_base::binary);
     bencode(std::ostream_iterator<char>(out), t.generate());
     emit updateProgress(100);
-    emit creationSuccess(save_path, full_path.branch_path().string().c_str());
+    emit creationSuccess(save_path, QString::fromUtf8(full_path.branch_path().string().c_str()));
   }
   catch (std::exception& e){
     emit creationFailure(QString::fromUtf8(e.what()));
