@@ -114,6 +114,8 @@ QList<QVariantMap> EventManager::getPropFilesInfo(QString hash) const {
     else
       file["progress"] = 1.; // Empty file...
     file["priority"] = priorities[i];
+    if(i == 0)
+      file["is_seed"] = h.is_seed();
     files << file;
     ++i;
   }
@@ -150,6 +152,7 @@ void EventManager::setGlobalPreferences(QVariantMap m) const {
       }
       int i = 0;
       foreach(const QString &new_folder, new_folders) {
+        qDebug("New watched folder: %s", qPrintable(new_folder));
         // Update new folders
         if(!old_folders.contains(new_folder)) {
           BTSession->getScanFoldersModel()->addPath(new_folder, download_at_path.at(i));
@@ -205,12 +208,6 @@ void EventManager::setGlobalPreferences(QVariantMap m) const {
     Preferences::setLSDEnabled(m["lsd"].toBool());
   if(m.contains("encryption"))
     Preferences::setEncryptionSetting(m["encryption"].toInt());
-  if(m.contains("peer_id"))
-    Preferences::setPeerID(m["peer_id"].toString());
-  if(m.contains("peer_version"))
-    Preferences::setClientVersion(m["peer_version"].toString());
-  if(m.contains("peer_build"))
-    Preferences::setClientBuild(m["peer_build"].toString());
   // Proxy
   if(m.contains("proxy_type"))
     Preferences::setPeerProxyType(m["proxy_type"].toInt());
@@ -292,9 +289,6 @@ QVariantMap EventManager::getGlobalPreferences() const {
   data["pex"] = Preferences::isPeXEnabled();
   data["lsd"] = Preferences::isLSDEnabled();
   data["encryption"] = Preferences::getEncryptionSetting();
-  data["peer_id"] = Preferences::getPeerID();
-  data["peer_version"] = Preferences::getClientVersion();
-  data["peer_build"] = Preferences::getClientBuild();
   // Proxy
   data["proxy_type"] = Preferences::getPeerProxyType();
   data["proxy_ip"] = Preferences::getPeerProxyIp();
@@ -373,10 +367,14 @@ void EventManager::modifiedTorrent(QTorrentHandle h)
   QVariantMap event;
   event["eta"] = QVariant(QString::fromUtf8("∞"));
   if(h.is_paused()) {
-    if(h.is_seed())
-      event["state"] = QVariant("pausedUP");
-    else
-      event["state"] = QVariant("pausedDL");
+    if(h.has_error()) {
+      event["state"] = QVariant("error");
+    } else {
+      if(h.is_seed())
+        event["state"] = QVariant("pausedUP");
+      else
+        event["state"] = QVariant("pausedDL");
+    }
   } else {
     if(BTSession->isQueueingEnabled() && h.is_queued()) {
       if(h.is_seed())
