@@ -201,7 +201,7 @@ signals:
 
 private:
   void addTorrentsFromDir(const QDir &dir, QStringList &torrents) {
-    const QStringList &files = dir.entryList(filters, QDir::Files, QDir::Unsorted);
+    const QStringList files = dir.entryList(filters, QDir::Files, QDir::Unsorted);
     foreach(const QString &file, files)
       torrents << dir.canonicalPath() + '/' + file;
   }
